==> freedroidrpg-0.16.tgz: share/freedroidrpg/map/titles/pt_BR/GameLost.lua <==
---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
text = [[
            Fim de Jogo

Por favor tente novamente, e quando tentar, certifique-se de comprar de nossos patrocinadores:

Dr. Como - "Poderosa tecnologia conveniente!"

Can4dian ph4rm4cy - "Amazing breakthrough herbal r3medies! 100% satisfaction guarant3ed!!!"

Soluções em Criogênicos - "Faça uma viagem rápida para o futuro com Soluções em Criogênicos!"

Futura Balística - "Além de balistica. Futura Balística."

MegaSystems - "O que você não quer fazer hoje?"

Masternak Rubbish Removal - "We CRUSH your RUBBISH."

Companhia Nicholson - "Segurança com uma vingança."

Sol Vermelho - "A noite acabou: experimente o amanhecer!"



Por favor tente novamente. Clique para continuar.
]]
}

==> freedroidrpg-0.16.1p5.tgz: share/freedroidrpg/map/titles/pt_BR/GameLost.lua <==
---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
text = [[
            Fim de Jogo

Por favor tente novamente, e quando tentar, certifique-se de comprar de nossos patrocinadores:

Dr. Como - "Poderosa tecnologia conveniente!"

F4m4ci4 C4n4dense - "Remédios Herbais 1ncrív3is! 100% satisfação garan7ida!"

Soluções em Criogênicos - "Faça uma viagem rápida para o futuro com Soluções em Criogênicos!"

Futura Balística - "Além de balistica. Futura Balística."

MegaSystems - "O que você não quer fazer hoje?"

Masternak Remoção de Lixo - "Nós ESMAGAMOS seu LIXO."

Companhia Nicholson - "Segurança com uma vingança."

Sol Vermelho - "A noite acabou: experimente o amanhecer!"



Por favor tente novamente. Clique para continuar.
]]
}
